@@ -16,6 +16,8 @@ __all__ = [
     'EditorError',
 ]
 
+__version__ = '0.4'
+
 
 class EditorError(RuntimeError):
     pass
@@ -24,6 +26,7 @@ class EditorError(RuntimeError):
 def get_default_editors():
     # TODO: Make platform-specific
     return [
+        'editor',
         'vim',
         'emacs',
         'nano',
@@ -31,7 +34,7 @@ def get_default_editors():
 
 
 def get_editor_args(editor):
-    if editor in ['vim', 'gvim']:
+    if editor in ['vim', 'gvim', 'vim.basic', 'vim.tiny']:
         return '-f -o'
 
     elif editor == 'emacs':
@@ -70,7 +73,7 @@ def get_editor():
 
 def edit(filename=None, contents=None):
     editor = get_editor()
-    args = get_editor_args(os.path.basename(editor))
+    args = get_editor_args(os.path.basename(os.path.realpath(editor)))
     args = [editor] + args.split(' ')
 
     if filename is None:
